#
# spec file for package wayland-protocols
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2015 Bjørn Lie, Bryne, Norway.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           wayland-protocols
Version:        1.32
Release:        2.1
Summary:        Wayland protocols that add functionality not available in the core protocol
License:        MIT
Group:          Development/Libraries/C and C++
URL:            https://wayland.freedesktop.org
Source:         https://gitlab.freedesktop.org/wayland/wayland-protocols/-/releases/%{version}/downloads/%{name}-%{version}.tar.xz
Source2:        https://gitlab.freedesktop.org/wayland/wayland-protocols/-/releases/%{version}/downloads/%{name}-%{version}.tar.xz.sig
Source3:        %{name}.keyring
%if 0%{?suse_version} > 1500
BuildRequires:  c++_compiler
BuildRequires:  c_compiler
%else
BuildRequires:  gcc11
BuildRequires:  gcc11-c++
%endif
BuildRequires:  meson >= 0.55.0
BuildRequires:  pkgconfig
BuildRequires:  python3-base
BuildRequires:  pkgconfig(wayland-scanner)
BuildArch:      noarch

%description
This package contains Wayland protocols that add functionality not
available in the Wayland core protocol. Such protocols either add
completely new functionality, or extend the functionality of some other
protocol either in Wayland core, or some other protocol in
wayland-protocols.

%package devel
Summary:        Wayland protocols that add functionality not available in the core protocol
Group:          Development/Libraries/C and C++

%description devel
This package contains Wayland protocols that add functionality not
available in the Wayland core protocol. Such protocols either add
completely new functionality, or extend the functionality of some other
protocol either in Wayland core, or some other protocol in
wayland-protocols.

%prep
%autosetup -p1

%build
%if 0%{?suse_version} <= 1500
export CC=gcc-11
export CXX=gcc-11
%endif
%meson
%meson_build

%install
%if 0%{?suse_version} <= 1500
export CC=gcc-11
export CXX=gcc-11
%endif
%meson_install

%check
%meson_test

%files devel
%doc README.md GOVERNANCE.md MEMBERS.md
%license COPYING
%{_datadir}/pkgconfig/%{name}.pc
%{_datadir}/%{name}/

%changelog
* Thu Oct 19 2023 Antonio Larrosa <alarrosa@suse.com>
- Use gcc11 in SLE15 in order to fix a ppc64le test that was
  failing when built with gcc7 (boo#1216320)
- Remove patch that doesn't seem to be needed anymore:
  * wayland-protocols-disable-pedantic-test-unstable-xdg-decoration-on-ppc64.patch
* Mon Jul  3 2023 llyyr <llyyr.public@gmail.com>
- Update to version 1.32:
  * ext-foreign-toplevel-list: new protocol
  * cursor-shape-v1: new protocol
  * security-context-v1: new protocol
  * xdg-shell: add suspended toplevel state
  * Apart from these new additions, this release also brings the
    usual clarifications, cleanups and fixes.
* Tue Nov 29 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 1.31:
  + wp-fractional-scale-v1: new protocol
  + xdg-shell: add defunct_role_object error
* Wed Nov 23 2022 llyyr <llyyr.public@gmail.com>
- Update to version 1.30:
  * This release introduces the new tearing-control protocol
* Mon Nov 14 2022 Fusion Future <qydwhotmail@gmail.com>
- Update to version 1.29:
  + linux-dmabuf: fix references to tranche_formats
  + content-type: fix enum name in
    wp_content_type_v1.set_content_type
- Changes from version 1.28:
  + xdg-shell:
  - Replace an HTTP link with HTTPS
  - window menus are optional
  - Add specific errors
  + Add xdg-shell.unresponsive error
  + xwayland_shell_v1: New protocol
* Mon Oct 10 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.27:
  + This release includes two new staging protocols:
  - Content type hint: This protocol enables clients to provide
    hints to the compositor about what kind of content it
    provides, allowing compositors to optionally adapt its
    behavior accordingly.
  - Idle notify: This extension allows compositors to notify
    clients about when the user is idle.
  + Apart from these two new extensions, this release also brings
    the usual clarifications, cleanups and fixes.
* Sat Sep 17 2022 Christophe Giboudeaux <christophe@krop.fr>
- Explicitly require a python3 interpreter to build
  wayland-protocols. It's needed to build the tests.
* Tue Jul 12 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.26:
  + This release introduces the new staging protocol single pixel
    buffer, which together with the viewporter extension enables
    clients to easily create arbitrarily sized single color
    surfaces.
  + Xdg-shell now also supports compositors announcing to surfaces
    some window management capabilities it supports.
  + The text input protocol saw a clarification to an easily
    misinterpreted paragraph, which if interpreted in a different
    way than the new clarification makes clear hindered correct
    behavior from being implemented.
  + This is also the first release which mandates new protocol
    extensions to follow RFC 2119 wording.
  + Apart from has so far been mentioned, this release also comes
    with the usual clarifications, improved annotations, and other
    minor fixes.
* Thu Feb 10 2022 Fusion Future <qydwhotmail@gmail.com>
- Update to 1.25
  * This release also adds a new staging protocol for session
    locking, as well as a 'bounds' event to the xdg_toplevel
    interface.
  * ext-session-lock-v1: new protocol
  * xdg-shell: add invalid_resize_edge error value
  * xdg-shell: Add toplevel "bounds" configure event
  * build: Bump version to 1.25
  * xdg-shell: clarify conditions for remapping unmapped surfaces
  * linux-dmabuf: fix typo in dev_t example code
* Wed Nov 24 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 1.24
  * This release adds feedback to the DMA buffer protocol
  * tests: allow cross-compiling the tests
  * tests: check whether -Wl,--unresolved-symbols=ignore-all is
    supported
  * meson.build: wayland-scanner is only needed for tests
  * Improve tiled_* enum summary
- Rebase wayland-protocols-disable-pedantic-test-unstable-xdg-decoration-on-ppc64.patch
* Thu Nov  4 2021 Yifan Jiang <yfjiang@suse.com>
- Add wayland-protocols-disable-pedantic-test-unstable-xdg-decoration-on-ppc64.patch:
  Temporarily disable the unstable xdg-decoration pedantic test on
  ppc64 until the upstream issue is more clearly diagnosed:
  https://gitlab.freedesktop.org/wayland/wayland-protocols/-/issues/48
* Wed Oct 13 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Run test-suite during build:
  + Add c_compiler and c++_compiler BuildRequires.
  + Stop passing tests=false to meson.
  + Add check section and meson_test macro.
* Wed Oct  6 2021 Fabian Vogt <fvogt@suse.com>
- Update to 1.23:
  * This release adds the new gesture "hold" to the pointer gesture protocol.
- Switch to building with meson
- Based on work from home:ngh
- Update description to fix grammar
* Wed Sep  1 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 1.22
  This release includes a new staging protocol: DRM object leasing.
  Besides that, various test and build system improvements are
  included, as well as a set of clarifications to the
  xdg-activation protocol and other protocols.
  * xdg-shell: Make xdg_surface fail when surface has role
  * xdg-output: fix minor calculation error
  * xdg-activation: correct sequence when X11 client spawns
    Wayland client
  * xdg-activation: rewrite and move description of token forwarding
  * xdg-activation-v1: clarify set_{serial,surface}
  * presentation-time: use enum entry description tags
- Check https://lists.freedesktop.org/archives/wayland-devel/2021-September/041972.html
  for the full list of changes.
* Sun May  9 2021 Dirk Müller <dmueller@suse.com>
- update to 1.21:
  * Also new with this release is the introduction of a new protocol phase
    that replaces the old "unstable" phase: "staging". The main purpose of
    this is making it more painless to transition a protocol from it's
    testing-in-production phase to declaring it stable. See README.md for
    details.
  * This release also introduces a new staging protocol: xdg-activation,
    meant to enable transferring focus between different toplevel surfaces.
    For example from a launcher to a launchee, or one focused application to
    another.
* Sun Mar  1 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.20:
  + This release includes the new governance document, describing
    how to introduce and update Wayland protocols in
    wayland-protocols. See the GOVERNANCE.md file for details.
- Changes from version 1.19:
  + This release includes a new xdg-shell protocol that adds
    support for repositioning already mapped popups. Methods of
    doing so with inter-surface synchronization has been left out,
    with the intention of addressing this with a protocol at a
    lower level.
  + Both the presentation time and xdg-shell protocol also got new
    attributes added meaning bindings using the enum and bitfield
    attributes will generate better result.
* Thu Jul 25 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.18:
  * This version comes with documentational clarifications, bug
    fixes and minor additions to existing protocols.
* Wed Nov 14 2018 bjorn.lie@gmail.com
- Update to version 1.17:
  * This versions include two new unstable protocols:
  - linux-explicit-synchronization: A Linux specific mechanism
    for explicit per-surface buffer synchronization.
  - primary-selection: A clipboard like mechanism mimicking
    primary selection on X11, commonly known as
    "middle-click-paste".
  * The license tag for the fullscreen shell was also corrected.
* Tue Jul 31 2018 bjorn.lie@gmail.com
- Update to version 1.16:
  * This version includes a new version of the unstable text-input
    protocol. The new version is not compatible with the old
    version. Please check the commit adding the new protocols for
    more details about the introduced changes.
  * The stable xdg-shell protocol got some clarifications about
    expectations regarding state requested by the client and what
    is configured by the compositor.
  * The xdg-output protocol got some clarifications about how
    transforms are handled.
  * The test suite was improved to catch issues detected by
    wayland-scanner.
* Sat Jul  7 2018 bjorn.lie@gmail.com
- Update to version 1.15:
  * This version includes a new unstable protocol that enables
    clients to allow the compositor to draw window decorations.
  * The xdg-shell protocol also saw a fix clarifying the
    requirements for xdg-popup parents.
* Thu May 17 2018 rzl@l2f.inesc-id.pt
- Update to version 1.14:
  * xdg-output: Add name and description events
  * configure.ac: Bump version to 1.14
  * xdg-shell: add enums for tiled window state to toplevel
    configure
* Sun Feb 18 2018 avindra@opensuse.org
- Update to version 1.13:
  * New unstable protocol: Input timestamps, a protocol for
    providing high resolution timestamps to input events. See
    commit 4f789286e4ab7f6fecc2ccb895d79362a9b2382a and protocol
    XML file for details.
- use https urls
* Thu Dec 28 2017 zaitor@opensuse.org
- Update to version 1.12:
  * This version includes the new stable version of the XDG Shell
    protocol. In short, the difference between the XDG Shell stable
    and the last unstable version include (among other things):
  * The base interface and the global exposed via the registry
    changed from zxdg_shell_v6 to xdg_wm_base.
  * Fullscreen semantics were better defined and geometry
    requirements relaxed to allow certain hardware optimizations.
  * The popup positioner was changed to allow positioning against a
    point.
  * The popup semantics was changed to allow future extendability.
  * Toplevel parent-child relationship ambiguities were fixed.
  * Unmap/map semantics were better defined.
  * Various other ambiguities were fixed and documentation in
    general was improved.
- Use autosetup macro, and drop make call, nothing is build anyway.
* Thu Nov  9 2017 aavindraa@gmail.com
- Update to version 1.11:
  * This version includes a new unstable version of the xdg-foreign
    protocol. The new version fixes C++ incompatibility issues
    while making the interface request naming a bit more
    descriptive.
  * Use sysroot prefix for pkgdatadir variable.
- Drop wayland-protocols-sysroot-prefix-fix.patch: Fixed upstream.
- Cleanup with spec-cleaner.
* Sat Sep  9 2017 zaitor@opensuse.org
- Add wayland-protocols-sysroot-prefix-fix.patch: Use sysroot
  prefix for pkgdatadir variable. The pc_sysroot is automatically
  added to cflags and libs but not to 'pkg-config --variable'.
* Tue Aug 22 2017 zaitor@opensuse.org
- Update to version 1.10:
  * This version introduces one new unstable protocol: xdg-output -
    a protocol meant for providing desktop centric concepts related
    to output and monitors to clients. It's for example intended to
    be used by Xwayland to be able to layout outputs on a logical
    pixel grid.
* Thu Jul 13 2017 zaitor@opensuse.org
- Update to version 1.9:
  * Keyboard shortcut inhibitation - a protocol meant for making it
    possible for virtual machine viewers, remote desktop clients
    etc, to be able to forward keyboard combinations such as
    Alt-Tab etc.
  * Xwayland keyboard grabbing - a protocol specifically targeted
    at enabling Xwayland to implement keyboard grabs.
- Update keyring, the previous one had expired.
* Sat Jun 17 2017 zaitor@opensuse.org
- Update to version 1.8:
  * Bumped the linux dmabuf protocol version, introducing a new
    request for creating a buffer from a dmabuf without having to
    wait for an event, as well as an event advertising supported
    fourcc modifiers along with the supported formats.
  * A pkg-config file meant for when wayland-protocols is used as a
    git submodule (or otherwise not installed) was added.
  * Various grammar fixes and clarifications were also included in
    this release.
* Sun Aug 21 2016 jengelh@inai.de
- Update to new upstream release 1.7
  * Includes the new version of the unstable xdg-shell v6 protocol.
  * The protocol have gone through extensive changes to how
    surfaces are created and mapped, and also adds a few features
    that was not possible before:
  - A client can now specify a minimum and/or maximum window
    geometry.
  - A client can now in a declarative manner position popup
    surfaces so that they will be visible to the user, e.g. by
    having them placed within the shell work area.
  - A client can map a popup without a grab; this intended to be
    used for relatively positioned child surfaces that should not
    be automatically dismissed, such as tooltips, and user
    interface elements like "popovers" in GTK+.
* Sat Aug 13 2016 zaitor@opensuse.org
- Update to version 1.6:
  * This release include two new unstable protocols:
  - xdg-foreign: reference a toplevel surface from another client
    and affect window manager relationship.
  - idle-inhibit: inhibit idle behaviour (screen blanking,
    screensaver, etc)
* Fri Jul 22 2016 jengelh@inai.de
- Update to new upstream release 1.5
  * This release include a new unstable version of the tablet
    protocol: tablet-unstable-v2. The new tablet protocol fixes a
    few issues discovered in the first version, and also adds pad
    support.
* Mon May 23 2016 zaitor@opensuse.org
- Update to version 1.4:
  * This release include one new stable protocol extension:
    viewporter.
  * The viewporter porter has previously been known as "wl_scaler"
    and enables a client to crop and scale a surface server side.
    Clients and compositors previously implementing support for
    wl_scaler should adapt accordingly. See the corresponding XML
    file for details.
  * Other changes included in this release are various grammatical
    corrections to the presentation-time, tablet, relative-pointer,
    pointer-constraints, linux-dmabuf, input-method and
    fullscreen-shell protocols.
  * It's now also possible to use autotools build files to install
    on platforms where the host CPU is not recognized.
* Fri Mar 18 2016 zaitor@opensuse.org
- Update to version 1.3:
  * This release include one new unstable protocol extension:
    Tablet support. See the corresponding XML file for details.
* Tue Mar  8 2016 zaitor@opensuse.org
- Update to version 1.2:
  * This release includes the first stable protocol extension:
    Presentation time. See the corresponding XML file for details.
  * Changes to existing protocols include: Pointer constaraints: A
    typo in the documentation was fixed.
* Tue Feb 16 2016 zaitor@opensuse.org
- Update to version 1.1:
  * This release includes two new unstable protocol extensions:
    + Relative pointer events.
    + Pointer constraints (locking and confinement).
  * Changes to existing protocols include:
    + xdg-shell: Added EFL state range reservation.
  * Other improvement include basic testing, which tests that all
    the protocols provided will pass wayland-scanner without any
    errors, and compatibility with older pkg-config versions.
- Add pkgconfig(wayland-scanner) BuildRequires: New dependency.
* Mon Feb  8 2016 jengelh@inai.de
- Add key files
* Thu Dec 17 2015 zaitor@opensuse.org
- Initial packaging (version 1.0) for build.opensuse.org
